require 'acceptance_helpers'

resource 'Institutions' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:institution) } }

  let(:institutions) { Institution.all }

  get '/v1/institutions' do
    parameter :limit, 'Limit of institutions'
    parameter :offset, 'Offset of institutions'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of institutions' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Institution.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/institutions/:id' do
    let(:id) { institutions.first.id }

    example 'Get an institution' do
      do_request
      expect(path).to eq("/v1/institutions/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Institution.find(id)))
      expect(status).to eq(200)
    end
  end

end
