require 'acceptance_helpers'

resource 'Languages' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  let(:languages) { Language.all }

  get '/v1/languages' do
    parameter :limit, 'Limit of languages'
    parameter :offset, 'Offset of languages'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of languages' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Language.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/languages/:id' do
    let(:id) { languages.first.id }

    example 'Get a language' do
      do_request
      expect(path).to eq("/v1/languages/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Language.find(id)))
      expect(status).to eq(200)
    end
  end

end
