require 'acceptance_helpers'
require 'shared/contexts'

resource 'Learning Objects' do

  before { 12.times { create(:learning_object) } }

  let(:learning_objects) { LearningObject.all }

  get '/v1/learning_objects' do
    parameter :limit, 'Limit of learning objects'
    parameter :offset, 'Offset of learning objects'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of learning objects' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(LearningObject.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/learning_objects/:id' do
    let(:id) { learning_objects.first.id }

    example 'Get a learning object' do
      do_request
      expect(path).to eq("/v1/learning_objects/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(LearningObject.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/learning_objects/:id/like' do
    include_context "authenticate_user"

    let(:id) { learning_objects.first.id }
  
    example 'Liking a learning object' do
      likes = learning_objects.first.likes.count
      do_request
      expect(path).to eq("/v1/learning_objects/#{id}/like")
      expect(JSON.parse(response_body)['count']).to eq(likes + 1)
      expect(status).to eq(201)
    end
  end

  delete '/v1/learning_objects/:id/like' do
    include_context "authenticate_user"

    let(:id) { learning_objects.first.id }
  
    before do
      create(:like, user: @user, likeable: learning_objects.first)
    end

    example 'Unliking a learning object' do
      likes = learning_objects.first.likes.count
      do_request
      expect(path).to eq("/v1/learning_objects/#{id}/like")
      expect(JSON.parse(response_body)['count']).to eq(likes - 1)
      expect(status).to eq(200)
    end
  end

end
