require 'acceptance_helpers'

resource 'MimeTypes' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:mime_type) } }

  let(:mime_types) { MimeType.all }

  get '/v1/mime_types' do
    parameter :limit, 'Limit of mime_types'
    parameter :offset, 'Offset of mime_types'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of mime_types' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(MimeType.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/mime_types/:id' do
    let(:id) { mime_types.first.id }

    example 'Get a mime_type' do
      do_request
      expect(path).to eq("/v1/mime_types/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(MimeType.find(id)))
      expect(status).to eq(200)
    end
  end

end
